use x86_64::structures::gdt::{Descriptor, GlobalDescriptorTable};

use lazy_static::lazy_static;

use super::asm::*;

use crate::{log_trace, format};
use crate::log::{LogLevel, LOGGER};

lazy_static! {
    pub static ref GDT: GlobalDescriptorTable = {
        let mut gdt = GlobalDescriptorTable::new();
        gdt.append(Descriptor::kernel_code_segment());
        gdt
    };
}

pub fn setup_gdt() {
    unsafe {
        interrupt_disable();
    }
    GDT.load();
    log_trace!(
        "GDT: Setting up global descriptor table at 0x{:x}",
        core::ptr::addr_of!(GDT) as usize
    );
    unsafe {
        interrupt_enable();
    }
}
