use fdt::*;
use lazy_static::lazy_static;
use limine::response::{DeviceTreeBlobResponse, RsdpResponse};

use crate::boot::{DTB_REQUEST, RSDP_REQUEST};
use crate::log::{LOGGER, LogLevel};
use crate::{format, log_trace};

lazy_static! {
    pub static ref DTB: Option<&'static DeviceTreeBlobResponse> = DTB_REQUEST.get_response();
    pub static ref RDSP: Option<&'static RsdpResponse> = RSDP_REQUEST.get_response();
}

#[allow(dead_code)]
pub fn device_tree_parsed() -> Option<Fdt<'static>> {
    if let Some(ok_dtb) = *DTB
        && let Ok(ok_parsed_dt) = unsafe { fdt::Fdt::from_ptr(ok_dtb.dtb_ptr() as *const u8) }
    {
        log_trace!("Device: Parsed device tree");
        Some(ok_parsed_dt)
    } else {
        None
    }
}
